@@ -2,8 +2,9 @@
 # Net::DNS::Resolver::Programmable
 # A Net::DNS::Resolver descendant class for offline emulation of DNS
 #
-# (C) 2006 Julian Mehnle <julian@mehnle.net>
-# $Id: Programmable.pm 7 2006-11-15 04:06:21Z julian $
+# (C) 2006-2007 Julian Mehnle <julian@mehnle.net>
+# Maintained from 2017 by David Precious (BIGPRESH) <davidp@preshweb.co.uk>
+
 #
 ##############################################################################
 
@@ -16,11 +17,11 @@ emulation of DNS
 
 =head1 VERSION
 
-0.002
+0.003
 
 =cut
 
-our $VERSION = '0.002';
+use version; our $VERSION = qv('0.004');
 
 use warnings;
 use strict;
@@ -133,7 +134,7 @@ For example:
 
 If both this and the C<records> option are specified, then statically
 programmed records are used in addition to any that are returned by the
-configured resolver code.  (FIXME?)
+configured resolver code.
 
 =item B<defnames>
 
@@ -191,8 +192,7 @@ methods.
 sub send {
     my $self = shift;
     
-    my $query_packet = $self->make_query_packet(@_);
-    my $question = ($query_packet->question)[0];
+    my $question = Net::DNS::Question->new(@_);
     my $domain   = lc($question->qname);
     my $rr_type  = $question->qtype;
     my $class    = $question->qclass;
@@ -205,7 +205,7 @@ sub send {
         ($result, $aa, @answer_rrs) = $resolver_code->($domain, $rr_type, $class);
     }
     
-    if (defined($Net::DNS::rcodesbyname{$result})) {
+    if (not defined($result) or defined($Net::DNS::rcodesbyname{$result})) {
         # Valid RCODE, return a packet:
         
         $aa     = TRUE      if not defined($aa);
@@ -276,7 +276,10 @@ included with Net::DNS::Resolver::Programmable.
 
 =head1 AUTHORS
 
-Julian Mehnle <julian@mehnle.net>
+David Precious (BIGPRESH) C<< <davidp@preshweb.co.uk> >> took on maintainership
+in July 2017
+
+Original author Julian Mehnle C<< <julian@mehnle.net> >>
 
 =cut
 
